@@ -81,6 +81,16 @@ QString QeMaemo5Notification::icon()
     return _icon;
 }
 
+QString QeMaemo5Notification::category()
+{
+    return _category;
+}
+
+QString QeMaemo5Notification::soundFile()
+{
+    return _soundFile;
+}
+
 void QeMaemo5Notification::setText(const QString &value)
 {
     _text = value;
@@ -99,6 +109,18 @@ void QeMaemo5Notification::setIcon(const QString &value)
     notify_notification_update(NOTIFY_NOTIFICATION(notification), QGSTRING(_title), QGSTRING(_text), QGSTRING(_icon));
 }
 
+void QeMaemo5Notification::setCategory(const QString &value)
+{
+    _category = value;
+    notify_notification_set_category(NOTIFY_NOTIFICATION(notification), QGSTRING(_category));
+}
+
+void QeMaemo5Notification::setSoundFile(const QString &value)
+{
+    _soundFile = value;
+    hildon_notification_set_sound(notification, QGSTRING(_soundFile));
+}
+
 int QeMaemo5Notification::timeout()
 {
     return _timeout;
