@@ -3,7 +3,11 @@
 #define QEMAEMO5ROTATOR_H
 
 //----------
-// Provides a means of WORKING automatic rotation for Maemo 5 apps. (The default Qt solution is buggy.)
+// Provides a means of automatic rotation for Maemo 5 apps.
+// --------
+// This is now DEPRECATED.
+// The original reason for the existence is that Qt's solution
+// was buggy in Qt 4.6. And that bug has been fixed.
 //----------
 
 #include <QWidget>
@@ -19,7 +23,7 @@ public:
         AutomaticBehavior = 0,
         LandscapeBehavior = 1,
         PortraitBehavior = 2,
-        StartupOnlyBehavior = 3,
+        StartupOnlyBehavior = 3
     };
 
     enum Orientation
